# `narwhals.selectors`

::: narwhals.selectors
    handler: python
    options:
      members:
        - boolean
        - by_dtype
        - categorical
        - numeric
        - string
      show_root_heading: false
      show_source: false
      show_bases: false
